PEP 257 plugin for py.test
=============

Minimal version of PEP 257 reports with py.test

Installation
============

Install with pip:

::

    pip install pytest-pep257


Usage
============

The files discovered by py.test will be checked with[https://pypi.python.org/pypi/pep257](pep257) by setting the flag `--pep257` as:

::

    py.test --pep257
